@@ -1,35 +1,41 @@
 """Tests for the `handler` module."""
 
+from __future__ import annotations
+
 import os
 from glob import glob
+from typing import TYPE_CHECKING
 
 import pytest
 from griffe.docstrings.dataclasses import DocstringSectionExamples, DocstringSectionKind
 
 from mkdocstrings_handlers.python.handler import CollectionError, PythonHandler, get_handler
 
+if TYPE_CHECKING:
+    from pathlib import Path
 
-def test_collect_missing_module():
+
+def test_collect_missing_module() -> None:
     """Assert error is raised for missing modules."""
     handler = get_handler(theme="material")
     with pytest.raises(CollectionError):
         handler.collect("aaaaaaaa", {})
 
 
-def test_collect_missing_module_item():
+def test_collect_missing_module_item() -> None:
     """Assert error is raised for missing items within existing modules."""
     handler = get_handler(theme="material")
     with pytest.raises(CollectionError):
         handler.collect("mkdocstrings.aaaaaaaa", {})
 
 
-def test_collect_module():
+def test_collect_module() -> None:
     """Assert existing module can be collected."""
     handler = get_handler(theme="material")
     assert handler.collect("mkdocstrings", {})
 
 
-def test_collect_with_null_parser():
+def test_collect_with_null_parser() -> None:
     """Assert we can pass `None` as parser when collecting."""
     handler = get_handler(theme="material")
     assert handler.collect("mkdocstrings", {"docstring_style": None})
@@ -44,7 +50,7 @@ def test_collect_with_null_parser():
     ],
     indirect=["handler"],
 )
-def test_render_docstring_examples_section(handler):
+def test_render_docstring_examples_section(handler: PythonHandler) -> None:
     """Assert docstrings' examples section can be rendered.
 
     Parameters:
@@ -57,13 +63,14 @@ def test_render_docstring_examples_section(handler):
         ],
     )
     template = handler.env.get_template("docstring/examples.html")
-    rendered = template.render(section=section)
+    rendered = template.render(section=section, locale="en")
+    template.render(section=section, locale="not_existing")
     assert "<p>This is an example.</p>" in rendered
     assert "print" in rendered
     assert "Hello" in rendered
 
 
-def test_expand_globs(tmp_path):
+def test_expand_globs(tmp_path: Path) -> None:
     """Assert globs are correctly expanded.
 
     Parameters:
@@ -81,14 +88,14 @@ def test_expand_globs(tmp_path):
     handler = PythonHandler(
         handler="python",
         theme="material",
-        config_file_path=tmp_path / "mkdocs.yml",
+        config_file_path=str(tmp_path.joinpath("mkdocs.yml")),
         paths=["*exp*"],
     )
-    for path in globbed_paths:  # noqa: WPS440
-        assert str(path) in handler._paths  # noqa: WPS437
+    for path in globbed_paths:
+        assert str(path) in handler._paths
 
 
-def test_expand_globs_without_changing_directory():
+def test_expand_globs_without_changing_directory() -> None:
     """Assert globs are correctly expanded when we are already in the right directory."""
     handler = PythonHandler(
         handler="python",
@@ -97,4 +104,4 @@ def test_expand_globs_without_changing_directory():
         paths=["*.md"],
     )
     for path in list(glob(os.path.abspath(".") + "/*.md")):
-        assert path in handler._paths  # noqa: WPS437
+        assert path in handler._paths
